#ifndef _yy_defines_h_
#define _yy_defines_h_

#define VAR 257
#define EXPR 258
#define ARRAY 259
#define STRUCT 260
#define UNION 261
#define ENUM 262
#define COMP 263
#define HASH 264
#define SEMI 265
#define MOD 266
#define OC 267
#define CC 268
#define DOLLAR 269
#define DOTDOTDOT 270
#define ENDFILE 271
#define GLOBAL 272
#define AUTO 273
#define STATIC 274
#define CONST 275
#define POLY 276
#define INTEGER 277
#define NATURAL 278
#define RATIONAL 279
#define REAL 280
#define STRING 281
#define FOREIGN 282
#define FILET 283
#define MUTEX 284
#define SEMAPHORE 285
#define CONTINUATION 286
#define THREAD 287
#define VOID 288
#define BOOL 289
#define FUNCTION 290
#define FUNC 291
#define EXCEPTION 292
#define RAISE 293
#define TYPEDEF 294
#define IMPORT 295
#define NEW 296
#define ANONINIT 297
#define NAMESPACE 298
#define PUBLIC 299
#define PROTECTED 300
#define EXTEND 301
#define WHILE 302
#define DO 303
#define FOR 304
#define SWITCH 305
#define BREAK 306
#define CONTINUE 307
#define RETURNTOK 308
#define FORK 309
#define CASE 310
#define DEFAULT 311
#define TWIXT 312
#define NAME 313
#define TYPENAME 314
#define NAMESPACENAME 315
#define COMMAND 316
#define NAMECOMMAND 317
#define TEN_NUM 318
#define OCTAL0_NUM 319
#define OCTAL_NUM 320
#define BINARY_NUM 321
#define HEX_NUM 322
#define TEN_FLOAT 323
#define OCTAL0_FLOAT 324
#define OCTAL_FLOAT 325
#define BINARY_FLOAT 326
#define HEX_FLOAT 327
#define CHAR_CONST 328
#define STRING_CONST 329
#define POLY_CONST 330
#define THREAD_CONST 331
#define COMMENT_CONST 332
#define VOIDVAL 333
#define BOOLVAL 334
#define DARROW 335
#define ISTYPE 336
#define HASMEMBER 337
#define POUND 338
#define COMMA 339
#define ASSIGN 340
#define ASSIGNPLUS 341
#define ASSIGNMINUS 342
#define ASSIGNTIMES 343
#define ASSIGNDIVIDE 344
#define ASSIGNDIV 345
#define ASSIGNMOD 346
#define ASSIGNPOW 347
#define ASSIGNSHIFTL 348
#define ASSIGNSHIFTR 349
#define ASSIGNLXOR 350
#define ASSIGNLAND 351
#define ASSIGNLOR 352
#define ASSIGNOR 353
#define ASSIGNAND 354
#define QUEST 355
#define COLON 356
#define OR 357
#define AND 358
#define LOR 359
#define LXOR 360
#define LAND 361
#define EQ 362
#define NE 363
#define LT 364
#define GT 365
#define LE 366
#define GE 367
#define SHIFTL 368
#define SHIFTR 369
#define PLUS 370
#define MINUS 371
#define TIMES 372
#define DIVIDE 373
#define DIV 374
#define POW 375
#define STARSTAR 376
#define POW2 377
#define POW3 378
#define UNIONCAST 379
#define UMINUS 380
#define BANG 381
#define FACT 382
#define LNOT 383
#define INC 384
#define DEC 385
#define STAR 386
#define AMPER 387
#define THREADID 388
#define OS 389
#define CS 390
#define DOT 391
#define ARROW 392
#define STAROS 393
#define CALL 394
#define OP 395
#define CP 396
#define POINTER 397
#define COLONCOLON 398
#define IF 399
#define TRY 400
#define NONL 401
#define ELSE 402
#define CATCH 403
#define NL 404
#ifdef YYSTYPE
#undef  YYSTYPE_IS_DECLARED
#define YYSTYPE_IS_DECLARED 1
#endif
#ifndef YYSTYPE_IS_DECLARED
#define YYSTYPE_IS_DECLARED 1
typedef union YYSTYPE {
    int		    ints;
    Value	    value;
    Class	    class;
    ArgType	    *argType;
    Type	    *type;
    Publish	    publish;
    ExprPtr	    expr;
    Atom	    atom;
    DeclListPtr	    declList;
    MemListPtr	    memList;
    Fulltype	    fulltype;
    ArgDecl	    argDecl;
    SymbolPtr	    symbol;
    NamespacePtr    namespace;
    CodePtr	    code;
    Bool	    bool;
    AtomListPtr	    atomList;
    FuncDecl	    funcDecl;
} YYSTYPE;
#endif /* !YYSTYPE_IS_DECLARED */
extern YYSTYPE yylval;

#endif /* _yy_defines_h_ */
